@@ -7,11 +7,14 @@ from .handlerhttppage import HttpPageHandler
 
 
 class DefaultUrlHandler(HttpPageHandler):
-    """
-    """
+    """ """
 
-    def __init__(self, url=None, contents=None, settings=None, request=None, url_builder=None):
-        super().__init__(url, settings=settings, request=request, url_builder=url_builder)
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
+        super().__init__(
+            url, settings=settings, request=request, url_builder=url_builder
+        )
         self.code = self.input2code(url)
 
     def get_page_url(self, url, crawler_name=None):
@@ -33,7 +36,9 @@ class DefaultUrlHandler(HttpPageHandler):
         request.crawler_type = None
 
         if self.url_builder:
-            url = self.url_builder(url=url, request=request, url_builder=self.url_builder)
+            url = self.url_builder(
+                url=url, request=request, url_builder=self.url_builder
+            )
             return url
 
 
@@ -41,4 +46,5 @@ class DefaultChannelHandler(DefaultUrlHandler):
     """
     Default handler for channels
     """
+
     pass
