@@ -10,7 +10,9 @@ class HandlerInterface(DefaultContentPage):
     this allows us to provide interface
     """
 
-    def __init__(self, url=None, contents=None, settings=None, request=None, url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         super().__init__(
             url,
             contents=contents,
