@@ -17,13 +17,19 @@ class RedditUrlHandler(DefaultUrlHandler):
     Maybe we could use python redditapi
     """
 
-    def __init__(self, url=None, contents=None, settings=None,request=None, url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         self.post_id = None
         self.subreddit = None
         self.social_data = {}
 
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
 
     def is_handled_by(self):
@@ -157,11 +163,17 @@ class RedditUrlHandler(DefaultUrlHandler):
 
 class GitHubUrlHandler(DefaultUrlHandler):
 
-    def __init__(self, url=None, contents=None, settings=None,request=None, url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         self.social_data = {}
 
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
 
     def is_handled_by(self):
@@ -260,7 +272,13 @@ class GitHubUrlHandler(DefaultUrlHandler):
 
 class ReturnDislike(DefaultUrlHandler):
     def __init__(
-        self, video_code=None, url=None, contents=None, settings=None, request=None, url_builder=None
+        self,
+        video_code=None,
+        url=None,
+        contents=None,
+        settings=None,
+        request=None,
+        url_builder=None,
     ):
 
         if video_code:
@@ -268,14 +286,21 @@ class ReturnDislike(DefaultUrlHandler):
             self.video_code = video_code
 
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
 
     def code2url(self, input_code):
         return "https://returnyoutubedislikeapi.com/votes?videoId=" + input_code
 
     def is_handled_by(self):
-        return self.url and self.url.find("https://returnyoutubedislikeapi.com/votes?videoId") >= 0
+        return (
+            self.url
+            and self.url.find("https://returnyoutubedislikeapi.com/votes?videoId") >= 0
+        )
 
     def load_response(self):
         response = self.get_response()
@@ -319,10 +344,16 @@ class ReturnDislike(DefaultUrlHandler):
 
 class HackerNewsHandler(DefaultUrlHandler):
 
-    def __init__(self, url=None, contents=None, settings=None, request=None, url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         self.social_data = {}
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
 
     def is_handled_by(self):
@@ -397,7 +428,9 @@ class HackerNewsHandler(DefaultUrlHandler):
 
 class InternetArchive(DefaultUrlHandler):
     def __init__(self, url, settings=None, request=None, url_builder=None):
-        super().__init__(url=url, settings=settings, request=request, url_builder=url_builder)
+        super().__init__(
+            url=url, settings=settings, request=request, url_builder=url_builder
+        )
 
     def is_handled_by(self):
         p = UrlLocation(self.url)
@@ -414,9 +447,15 @@ class InternetArchive(DefaultUrlHandler):
 
 
 class FourChanChannelHandler(DefaultChannelHandler):
-    def __init__(self, url=None, contents=None, settings=None, request=None,url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
 
         if url:
@@ -457,9 +496,15 @@ class FourChanChannelHandler(DefaultChannelHandler):
 
 class TwitterUrlHandler(DefaultUrlHandler):
 
-    def __init__(self, url=None, contents=None, settings=None, request=None, url_builder=None):
+    def __init__(
+        self, url=None, contents=None, settings=None, request=None, url_builder=None
+    ):
         super().__init__(
-            url=url, contents=contents, settings=settings, request=request, url_builder=url_builder
+            url=url,
+            contents=contents,
+            settings=settings,
+            request=request,
+            url_builder=url_builder,
         )
         wh = self.url.find("?ref_src=")
         if wh >= 0:
