@@ -9,11 +9,13 @@ class RemoteUrl(ContentInterface):
         self.server = RemoteServer(remote_server_location)
         self.all_properties = None
         self.social_properties = None
+        self.responses = None
 
     def get_responses(self):
         if self.all_properties is None:
             self.all_properties = self.server.get_getj(self.url)
 
+        if not self.responses:
             self.responses = {"Default": RemoteServer.get_response(self.all_properties)}
 
         return self.responses
@@ -106,7 +108,7 @@ class RemoteUrl(ContentInterface):
         if self.all_properties is not None:
             feeds = self.get_properties().get("feeds")
         else:
-            feeds_json = self.server.get_feedsj(url = self.url)
+            feeds_json = self.server.get_feedsj(url=self.url)
             feeds = feeds_json.get("feeds")
 
         if feeds is None:
